==> webkit2gtk_2.19.92.orig.tar.xz: webkitgtk-2.19.92/Tools/TestWebKitAPI/Tests/WebCore/SharedBufferTest.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SharedBufferTest.h"

#include <WebCore/FileSystem.h>
#include <wtf/MainThread.h>

using namespace WebCore;

namespace TestWebKitAPI {

void SharedBufferTest::SetUp()
{
    WTF::initializeMainThread();

    // create temp file
    FileSystem::PlatformFileHandle handle;
    m_tempFilePath = FileSystem::openTemporaryFile("tempTestFile", handle);
    FileSystem::writeToFile(handle, testData(), strlen(testData()));
    FileSystem::closeFile(handle);

    m_tempEmptyFilePath = FileSystem::openTemporaryFile("tempEmptyTestFile", handle);
    FileSystem::closeFile(handle);
}

void SharedBufferTest::TearDown()
{
    FileSystem::deleteFile(m_tempFilePath);
    FileSystem::deleteFile(m_tempEmptyFilePath);
}

} // namespace TestWebKitAPI

==> webkit2gtk_2.36.4.orig.tar.xz: webkitgtk-2.36.4/Tools/TestWebKitAPI/Tests/WebCore/SharedBufferTest.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SharedBufferTest.h"

#include <wtf/FileSystem.h>
#include <wtf/MainThread.h>

namespace TestWebKitAPI {

void FragmentedSharedBufferTest::SetUp()
{
    WTF::initializeMainThread();

    // create temp file
    FileSystem::PlatformFileHandle handle;
    m_tempFilePath = FileSystem::openTemporaryFile("tempTestFile", handle);
    FileSystem::writeToFile(handle, testData(), strlen(testData()));
    FileSystem::closeFile(handle);

    m_tempEmptyFilePath = FileSystem::openTemporaryFile("tempEmptyTestFile", handle);
    FileSystem::closeFile(handle);
}

void FragmentedSharedBufferTest::TearDown()
{
    FileSystem::deleteFile(m_tempFilePath);
    FileSystem::deleteFile(m_tempEmptyFilePath);
}

} // namespace TestWebKitAPI
